<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Zamknij (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Zwiń</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Rozwiń</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Zamknij powiadomienie</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln słowo</numerusform>
            <numerusform>%Ln słowa</numerusform>
            <numerusform>%Ln słów</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuta</numerusform>
            <numerusform>%Ln minuty</numerusform>
            <numerusform>%Ln minut</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% z %Ln minuty</numerusform>
            <numerusform>%L1% z %Ln minut</numerusform>
            <numerusform>%L1% z %Ln minut</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% z %Ln słowa</numerusform>
            <numerusform>%L1% z %Ln słów</numerusform>
            <numerusform>%L1% z %Ln słów</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Dzienny postęp</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Najdłuższy triumf</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Obecny triumf</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>niedostępne</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n dzień</numerusform>
            <numerusform>%n dni</numerusform>
            <numerusform>%n dni</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% dziennego celu</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Ustaw język</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Bez tytułu %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Tylko-do-odczytu)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Przepraszam</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Nie można zapisać pliku &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Zapisz plik jako</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Nie można nadpisać pliku &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Zmień nazwę pliku</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Nie można zmienić nazwy pliku &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Wczytać ponownie plik?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Wczytać ponownie plik &apos;%1&apos; z dysku?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Wszystkie niezapisane zmiany zostaną utracone</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Wczytaj ponownie</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Bez nazwy %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Zapisanie jako zwykły tekst usunie całe formatowanie. Usunąć formatowanie?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Plik zmieniony</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Plik &apos;%1&apos; został zmieniony przez inny program.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Czy chcesz wczytać plik ponownie?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Wczytaj ponownie</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignoruj</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Plik usunięty</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Plik %1 został usunięty przez inny program.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Czy chcesz zapisać, czy zamknąć plik?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nie można otworzyć archiwum.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Znajdź:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Zastąp:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignoruj wielkość liter</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Tylko całe wyrazy</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Wyrażenia regularne</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Znajdź poprzedni</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Znajdź następny</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Znajdź</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Zastąp</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Zastąp &amp;wszystkie</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Znajdź</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Zastąp</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Zastąpić %n wystąpienie?</numerusform>
            <numerusform>Zastąpić %n wystąpienia?</numerusform>
            <numerusform>Zastąpić %n wystąpień?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Przepraszam</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Nie znaleziono wyrażenia.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>Dokument tekstowy OpenDocument</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Tekst z formatowaniem</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Zwykły tekst</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Wszystkie obsługiwane typy plików</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Sprawdź pisownię...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Nie znaleziono propozycji)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Otwórz obrazek</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Obrazki</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Wybierz język aplikacji:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Język systemowy&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Informacja</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Zmiany zostaną uwzględnione przy następnym uruchomieniu programu.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nie można otworzyć archiwum.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferencje</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statystyki</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Pasek narzędzi</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Sprawdzanie pisowni</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Wybierz słownik</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Przepraszam</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nie można otworzyć archiwum.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Archiwum nie zawiera prawidłowego słownika.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Jeden lub więcej skrótów się powtarza. Czy chcesz kontynuować?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Słowniki &quot;%1&quot; już istnieje. Czy chcesz go zastąpić?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Dzienny cel</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minuty:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Słowa:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Edycja</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Zawsze wyśrodkuj w pionie</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Kursor blokowy</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Wygładzone czcionki</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Odgłosy maszyny do pisania</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Eleganckie cudzysłowy:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Podwójne</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Pojedyncze</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Sceny</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Sekwencja podziału</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Zapisywanie</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Pamiętaj pozycję kursora</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Licznik słów</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Licznik stron</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Licznik akapitów</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Licznik znaków</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Znaki:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Akapity:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algorytm zliczania słów</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Czy zresetować licznik dziennego postępu?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Zapisz znacznik kolejności bajtów w prostych plikach tekstowych</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Domyślny format:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Zresetuj Dzisiaj</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Zapamiętaj historię</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Pokaż triumfy</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Minimalny postęp dla triumfu:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Wykrywaj granice słów</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Dziel liczbę znaków przez sześć</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Zliczaj każdą literę jako slowo</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algorytm zliczania słów</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Styl</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Tylko ikony</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Tylko tekst</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Tekst obok ikon</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Tekst pod ikonami</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Położenie tekstu:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Działania</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Przesuń w górę</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Przesuń w dół</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Dodaj odstęp</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Polecenie</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Skrót</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Działanie</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Sprawdzaj pisownię podczas pisania</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ignoruj słowa pisane WIELKIMI LITERAMI</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Ignoruj słowa z liczbami</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Język</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Osobisty słownik</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Usunąć obecny słownik?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Interfejs użytkownika</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Zawsze wyświetlaj pasek przewijania</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Zawsze wyświetlaj górny pasek</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Zawsze wyświetlaj dolny pasek</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>To nie jest obsługiwany plik RTF.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Niespodziewanie osiągnięto koniec pliku.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+W dół</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Przenieś sceny w górę</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+W górę</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Pokaż/Ukryj listę scen</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Pokaż listę scen (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Ukryj listę scen (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtruj</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Przenieś sceny w dół</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Zmień rozmiar listy scen</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Domyślna</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Zarządzanie sesjami</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;esje</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nowa</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Stwórz kopię </translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Przełącz na</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nowa sesja</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Stwórz kopię sesji</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Zmień nazwę sesji</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Usunąć wybraną sesję?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Nazwa sesji:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Przepraszam</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Podana nazwa sesji już jest używana.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nowa...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>Za&amp;rządzaj...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Przywróć domyślny</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Skrót:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Zamienianie cudzysłowów...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Proszę czekać</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Sprawdź pisownię</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Dodaj</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignoruj</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Ignoruj &amp;wszystkie</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Zamień</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Zamień w&amp;szystkie</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Nie ma w słowniku:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Zamień na:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Sprawdzanie pisowni...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Proszę czekać</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Kontynuuj sprawdzanie od początku pliku?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Zakończono sprawdzanie pisowni.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Symbole</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Ostatnio używane symbole</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Wszystkie symbole</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Szczegóły</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Wstaw</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Bloki</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Skrypty</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Bez nazwy %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Brak obrazka</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Sąsiadująco</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Wyśrodkowane</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Rozciągnięte</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Przeskalowane</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Powiększone</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Nieprzezroczystość:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Położenie:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Szerokość:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Okrągłe rogi tła tekstu </translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Promień:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Rozmycie tła tekstu</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Cień tła tekstu</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Przesunięcie pionowe:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Marginesy zewnętrzne</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Okno:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Strona:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Wcięcie pierwszego wiersza</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Powyżej:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Poniżej:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Edytuj motyw</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Tło okna</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Rodzaj:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Kolor:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Obrazek:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> pikseli</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Po lewej</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Tło tekstu</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Po prawej</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Czcionka:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Błędne wyrazy:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Odstęp między wierszami</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Pojedynczy</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1,5 wiersza</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Podwójny</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporcjonalny</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Wysokość:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Odstępy między akapitami</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Szerokość zakładki:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nowy motyw</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Motywy</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Domyślny</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Delikatny Blues</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Stara szkoła</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Marzenia kosmiczne</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Biurko</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Stwórz kopię </translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Własny</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importuj</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportuj</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Usunąć motyw &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Motywy (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Importuj motyw</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Eksportuj motyw</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Gorzkie Nieba</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Oczarowanie</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Szpiegowskie gry</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Spokój</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Usunąć odliczanie?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Słowa:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Strony:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Akapity:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Znaki:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Ustaw opóźnienie</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Ustaw czas</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Opóźnienie:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Czas:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Rodzaj:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Memo:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Nie ma włączonego odliczania</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Odliczanie</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nowe</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Poprzednie</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Anulować edycję odliczania?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Wczytywanie motywów</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Wczytywanie dźwięków</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Bez tytułu</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otwórz plik</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>O programie FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Prosty pełnoekranowy procesor tekstu</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Udostępniony na licencji &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Korzysta z ikon motywu &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Udostępnionych na licencji &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Znaki: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Strony: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Akapity: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Słowa: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otwieranie %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Bez tytułu %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Przeglądaj wszystkie dokumenty</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Przełącz do następnego dokumentu</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Przełącz do poprzedniego dokumentu</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Przełącz do pierwszego dokumentu</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Przełącz do ostatniego dokumentu</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Przełącz do dokumentu %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Wczytywanie ustawień</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Bufor awaryjny nie jest zapisywalny.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>Program FocusWriter nie został zamknięty prawidłowo.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Przywrócić z bufora awaryjnego?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Niektórych plików nie można otworzyć.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Niektóre pliki zostały otwarte tylko do odczytu.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; jest nowszy niż zachowana kopia.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Nadpisać nowszy plik?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Zapisać zmiany?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Zapisać zmiany w pliku &apos;%1&apos; przed zamknięciem?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Twoje zmiany zostaną utracone, jeśli ich nie zapiszesz.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Nie można załadować odgłosów maszyny do pisania.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nowy</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Otwórz...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>&amp;Przeładuj</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Zapisz</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Zapisz &amp;jako...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>Z&amp;mień nazwę...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Zapisz &amp;wszystko</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Zarządzanie sesjami</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nowa sesja</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Drukuj...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Z&amp;amknij</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Za&amp;kończ</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edycja</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Cofnij</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Przyw&amp;róć</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Wy&amp;tnij</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiuj</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Wklej</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Wklej &amp;bez formatowania</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>&amp;Zaznacz wszystko</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Zaznacz &amp;scenę</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>&amp;Format</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>Pogru&amp;bienie</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Kursywa</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>P&amp;odkreślenie</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Przek&amp;reślenie</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Indeks &amp;górny</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>Indeks &amp;dolny</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Wyrównaj do &amp;lewej</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Wyrównaj do środk&amp;a</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Wyrównaj do &amp;prawej</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Wyrównaj do ob&amp;u stron</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>Z&amp;mniejsz wcięcie</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Z&amp;większ wcięcie</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Blok od l&amp;ewej do prawej</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Blok od prawe&amp;j do lewej</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Narzędzia</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Znajdź...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Znajdź &amp;następny</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Znajdź &amp;poprzedni</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>Za&amp;stąp...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Eleganckie &amp;cudzysłowy</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Aktualizuj &amp;dokument</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Aktualizuj z&amp;aznaczenie</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Sp&amp;rawdzanie pisowni...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Ustaw &amp;język...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Odliczanie...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;ymbole...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Dzienny postęp</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Wyświetlaj pasek &amp;narzędzi</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Wyświetlaj &amp;ikony w menu</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>P&amp;odświetlanie tekstu</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Tryb pełno&amp;ekranowy</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>Minimalizu&amp;j</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Motywy...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferencje...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Wyłącz podświetlanie</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Podświetl jeden wiersz</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Podświetl trzy wiersze</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Akapit</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Podświetl akapit</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>P&amp;omoc</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Zmiana języka aplikacji...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Niektóre pliki nie są obsługiwane i nie mogły być otwarte.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Wyłączone</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>&amp;Jeden wiersz</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Trzy wiersze</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Informacje o programie</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Informacje o &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Ustawienia &amp;strony...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Nagłówek</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Nagłówek &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Nagłówek &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Nagłówek &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Nagłówek &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Nagłówek &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Nagłówek &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normalnie</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Aktualizuj cudzysłowy drukarskie dokumentu</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Aktualizuj cudzysłowy drukarskie wyboru</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
